////////////////////////////////////////////////////////////////////////////////
//DEXi: Implements a Multi-Attribute Decision Making algorithm developed by
//dr. Marko Bohanec (http://www-ai.ijs.si/MarkoBohanec/dex.html)
//
//Copyright (C) 2004 Asobi d.o.o. (www.asobi.si)
//Authors: dr. Marko Bohanec, Dusan Omercevic, Andrej Kogovsek
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////
package si.DEXi;

import org.w3c.dom.*;

import java.io.IOException;
import java.io.OutputStream;

import java.util.*;


/**
 * Scale class
 * @author Andrej Kogov\u0161ek, Du\u0161an Omer\u010Devi\u0107
 * @version 1.0
 */
public class Scale {
    private Integer size;
    private Vector scaleValues;

    /**
     * Constructor with Element parameter
     * @param element XML object
     */
    public Scale(final Element element) {
        NodeList nodes = element.getChildNodes();
        scaleValues = new Vector();

        for (int i = 0; i < nodes.getLength(); i++) {
            Node node = nodes.item(i);

            if (node.hasChildNodes()) {
                ScaleValue scaleValue = new ScaleValue((Element) node);
                scaleValues.addElement(scaleValue);
            }
        }

        setSize(new Integer(scaleValues.size()));
    }

    /**
     * Find string value
     * @param strValue String object parameter
     * @return Object value if value found;
     *  if not then return null
     */
    public Value findValue(final String strValue) {
        Value value = null;

        for (int i = 0; i < scaleValues.size(); i++) {
            ScaleValue scaleValue = (ScaleValue) scaleValues.get(i);

            if (scaleValue.getName().equals(strValue)) {
                value = new Value(scaleValue.getName(), new Integer(i));
            }
        }

        return value;
    }

    /**
     * Find ordinal value
     * @param ordinal Integer object parameter
     * @return Object value if value found;
     *  if not then return null
     */
    public Value findValue(final Integer ordinal) {
        Value value = null;

        if (ordinal.intValue() < scaleValues.size()) {
            ScaleValue scaleValue = (ScaleValue) scaleValues.elementAt(ordinal
                    .intValue());
            value = new Value(scaleValue.getName(), ordinal);
        }

        return value;
    }

    /**
     *
     * @return Integer
     */
    public Integer getSize() {
        return this.size;
    }

    /**
     * Print object values to OutputStream
     * @param stream OutputStream object parameter
     * @throws IOException Throws exception if stream cannot write
     */
    public void print(final OutputStream stream) throws IOException {
        stream.write(("Scale: \n" + "Size: \n" + getSize() + "\n").getBytes());

        for (int i = 0; i < scaleValues.size(); i++) {
            stream.write(("scaleValue[" + i + "]: \n").getBytes());

            ScaleValue scaleValue = (ScaleValue) scaleValues.elementAt(i);
            scaleValue.print(stream);
        }
    }

    /**
     * Set size value
     * @param aSize Integer object parameter
     */
    protected void setSize(final Integer aSize) {
        this.size = aSize;
    }
}
