////////////////////////////////////////////////////////////////////////////////
//DEXi: Implements a Multi-Attribute Decision Making algorithm developed by
//dr. Marko Bohanec (http://www-ai.ijs.si/MarkoBohanec/dex.html)
//
//Copyright (C) 2004 Asobi d.o.o. (www.asobi.si)
//Authors: dr. Marko Bohanec, Dusan Omercevic, Andrej Kogovsek
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU Lesser General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//Lesser General Public License for more details.
//
//You should have received a copy of the GNU Lesser General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
////////////////////////////////////////////////////////////////////////////////
package si.DEXi;

import java.util.Vector;


/**
 * VariableList class
 * @author Andrej Kogov\u0161ek, Du\u0161an Omer\u010Devi\u0107
 * @version 1.0
 */
public class VariableList {
    private Vector variables;

    /**
     * Constructor with list parameter
     * @param list String object parameter
     */
    public VariableList(final String list) {
        String[] hash = null;

        if (list == null) {
            variables = new Vector();
        } else {
            hash = list.split(";");
            variables = new Vector();

            for (int i = 0; i < hash.length; i++) {
                if ((i > 0) && (findVariable(hash[i].split("=")[0]) != null)) {
                    throw new IllegalArgumentException(
                        "VariableList: Variable with this name already exists");
                }

                Variable variable = new Variable(hash[i]);
                variables.add(variable);
            }
        }
    }

    /**
     * Find variable by name
     * @param name String object parameter
     * @return Variable; return empty variable object if not found
     */
    public Variable findVariable(final String name) {
        Variable variable = null;

        for (int i = 0; i < variables.size(); i++) {
            Variable var = (Variable) variables.get(i);

            if (var.getName().equals(name)) {
                variable = var;
            }
        }

        return variable;
    }
}
